// Example/template scene file for using p_surf.inc

#include "colors.inc"

//global_settings { max_trace_level 8 }

#declare MakeTriangles=1; //**
// Set MakeTriangles to 1 to make surface from scratch.
// Set MakeTriangles to 0 to force reading triangles from TriangleDataFileName
// The first time you render a particular surface, you will have
// set MakeTriangles to 1.


#declare TriangleDataFileName="hnnbrg.dat" //**
// The name of a file to write/read triangles to/from.
// If making a new mesh, TriangleDataFileName is the
// name the triangles are written to so they can
// be used on another run without recalculating them.
// If MakeTriangles is set to 0, TriangleDataFileName is
// the file the triangles will be read from.

#declare use_smooth_triangles=1;//**
// If use_smooth_triangles is set to 0, only triangles (no normals) are generated
// There is currently no checking of what type of triangles (smooth or plane)
// they are when reading, so you have to use the same setting for use_smooth_triangles
// that was set when the triangles were written.

/* -------------- Textures -------------------------------*/
#include "snog.inc" // The textures are in a separate file 
                    // to keep this file a little cleaner

/*--------------------------------------------------------*/
// "//**" = required by p_surf.inc if we are making new triangles
#declare uusteps = 40;		//**
#declare vvsteps = 80;		//**

// Limits for the surface parameters 
#declare uumin   =  0;		//**
#declare uumax   =  1;          //**
#declare vvmin   =  0; 		//**
#declare vvmax   =  2*pi; 	//**


/* Parametric equations for the particular surface we are making */
                                                                 
// a couple of 'utility functions'                                                                 
#macro Cosh(b)
	(exp(b)+exp(-b))/2
#end
#macro Sinh(b)
	(exp(b)-exp(-b))/2
#end

// the surface
#macro Henneberg(uu,vv)
<       
        // x
	2*Sinh(uu)*cos(vv)-2/3*Sinh(3*uu)*cos(3*vv),
	// y
	2*Sinh(uu)*cos(vv)-2/3*Sinh(3*uu)*sin(3*vv),
	// z 
	2*Cosh(2*uu)*cos(2*vv)	
>
#end

// Have to set XYZ to our desired surface.
// XYZ is the macro actually called in p_surf.inc
#macro XYZ(uu,vv)	//**
	Henneberg(uu,vv)
#end


#if(MakeTriangles)
	#declare WriteTrianglesTo=TriangleDataFileName
	// to *not* write out a triangle datafile when MakeTriangles is 
	// set, just make sure WriteTrianglesTo is not defined.
        // (e.g. comment out the above line)
#else
	#declare ReadTrianglesFrom=TriangleDataFileName
#end                                                                     

/* --------Constructing the surface------------------------------------*/
#include "p_surf.inc" //**
// p_surf.inc uses the above declarations to make 
// a triangle mesh named 'p_surface'

object{
	union{
          object{
                        p_surface // from p_surf.inc
                        
                        // snog is defined in "snog.inc"
			texture {snog scale 3}

          }
          // just to demonstrate the p_edge macro:
          object{p_edge(MAXUU,100,.1) texture{pigment{Red}}}
	}
	rotate <0,70,0>
	scale 1
}

camera
{ 
	location  < 16, 11,-16>
	look_at   < 0, 0, 0>
} 

light_source { <20, 10, -20> color rgb 1 }

// skypigment is defined in "snog.inc"
sky_sphere{pigment{skypigment scale .5}}
 
