// kuen.pov

#include "colors.inc"

#if (version<3.1)
	#error "This file requires features of POV-Ray version 3.1 (or later?)"
#end    


#declare MakeTriangles=1; //**

#declare TriangleDataFileName="kuen.dat" //** 

#declare use_smooth_triangles=1;//**


//** stuff which must be declared before including p_surf.inc
//** or p_surf.inc
// number of u,v steps
#declare uusteps = 60;   //**Number of u steps
#declare vvsteps = 60;    //**Number of v steps

#declare keps=(pi+.01)/vvsteps;

// u,v limits:
#declare uumin  = -4.5;         //**
#declare uumax  =  4.5;         //**
#declare vvmin  = keps;         //**
#declare vvmax  =  pi-keps;     //**

// p_surf.inc expects a vector valued macro
// named 'xyz(uu,vv)'

#macro Kuen(uu,vv)
  #local xx= 2*(cos(uu)+uu*sin(uu))*sin(vv)/(1+uu*uu*sin(vv)*sin(vv));
  #local yy= 2*(sin(uu)-uu*cos(uu))*sin(vv)/(1+uu*uu*sin(vv)*sin(vv));
  #if(vv >0 & vv/2 < pi/2)
      #local zz=log(tan(vv/2))+2*cos(vv)/(1+uu*uu*sin(vv)*sin(vv));
  #else
      #if(vv<=0)
         #local zz=log(tan(keps/2))+2*cos(vv)/(1+uu*uu*sin(vv)*sin(vv));
      #else
         #local zz=log(tan(pi/2-keps/2))+2*cos(vv)/(1+uu*uu*sin(vv)*sin(vv));
      #end    
  #end
  <xx,yy,zz>
#end


#macro XYZ(uu,vv) //**
	Kuen(uu,vv)
#end

#declare use_smooth_triangles=1;//** must be set (0 or 1)
#if(MakeTriangles)
	
	#declare WriteTrianglesTo=TriangleDataFileName
#else
	#declare ReadTrianglesFrom=TriangleDataFileName
#end

// if the macro 'mytexture1(c1,c2)' is defined, it will
// be applied to individual triangles. when called,
// count1 refers to uu steps and count2 is vv steps
#include "woods.inc"

#macro mytexture1(uucount,vvcount) //**
        #local oddcount=mod(uucount+vvcount,2); 
	#if(oddcount)	//'odd'
	        texture{T_Wood32}
        #else		//'even'
                texture{T_Wood31}
	#end
#end

#include "p_surf.inc"  

object{ 
        p_surface
        #ifndef(mytexture1)
                texture{
                        pigment {color rgb < .38, .43, .68>}
                        finish {
			        ambient 0.1 
			        specular 0.7 
			        reflection .3
			        brilliance 8         	
                        }
                }
        #end
	rotate <90, 0,0>     
	scale 1.2
}
light_source { <-290, -230,100> color rgb 1 }
light_source { <230, 200, 150> color rgb 1 }


background{rgb<.6,.6,.65>}
camera{ 
	location  1.0*< 1, 2, 4>
	look_at   < 0, .1, 0>
} 
