// Example/template scene file for using p_surf.inc


#include "colors.inc"

//global_settings { max_trace_level 8 }

#declare MakeTriangles=1; //**
// Set MakeTriangles to 1 to make a new surface (from scratch).
// Set MakeTriangles to 0 to force reading triangles from TriangleDataFileName
// The first time you render a particular surface, you will have
// set MakeTriangles to 1.


#declare TriangleDataFileName="curlyhorn.dat" //**
// The name of a file to write/read triangles to/from.
// If making a new mesh, TriangleDataFileName is the
// name the triangles are written to so they can
// be used on another run without recalculating them.
// If MakeTriangles is set to 0, TriangleDataFileName is
// the file the triangles will be read from.

#declare use_smooth_triangles=1;//**
// If use_smooth_triangles is set to 0, only triangles (no normals) are generated
// There is currently no checking of what type of triangles (smooth or plane)
// they are when reading, so you have to use the same setting for use_smooth_triangles
// that was set when the triangles were written.



/*--------------------------------------------------------*/
// "//**" = required by p_surf.inc if we are making new triangles
#declare uusteps = 60;		//**
#declare vvsteps = 60;		//**


// Limits for the surface parameters
#declare uumin   =  .25*pi;	//**
#declare uumax   =  2.65*pi;    //**
#declare vvmin   =  0; 		//**
#declare vvmax   =  2*pi; 	//**


/* Parametric equations for the particular surface we are making */
                                                                 
// the surface
#macro curlyhorn(uu,vv)
<       
(3 + .2*uu*cos(vv))*cos(uu),
(3 + .2*uu*cos(vv))*sin(uu),
.2*uu*sin(vv)+uu/2
>
#end

// Have to set XYZ to our desired surface.
// XYZ is what is actually called in p_surf.inc
#macro XYZ(uu,vv)	//**
	curlyhorn(uu,vv)
#end


#if(MakeTriangles)
	#declare WriteTrianglesTo=TriangleDataFileName
	// to *not* write out a triangle datafile when MakeTriangles is 
	// set, just make sure WriteTrianglesTo is not defined.
	// (e.g. comment out the above line)
	
#else
	#declare ReadTrianglesFrom=TriangleDataFileName
#end

/* --------Constructing the surface------------------------------------*/
#include "p_surf.inc" //**
// p_surf.inc uses the above declarations to make 
// a triangle mesh named 'p_surface'

object{
	union{
          object{
                        p_surface // the result of p_surf.inc
                        

			texture{
			        pigment{rgb<.4,.6,.7>}
			        finish{phong .60 phong_size 40}
			}

          }
          // uncomment to demonstrate the p_edge macro:
          // object{p_edge(MAXUU,50,.1) texture{pigment{Red}}}
	}
	rotate <0,230,0>
	scale 2.5
}

camera
{ 
	location  < 16, 11,-16>
	look_at   < 0, 3, -7>
} 

light_source { <20, 10, -20> color rgb 1 }
  
background{<.7,.7,.75>}  

 
