// Example/template scene file for using p_surf.inc

#include "colors.inc"

global_settings { max_trace_level 10 }

#declare MakeTriangles=1; //**
// Set MakeTriangles to 1 to make surface from scratch.
// Set MakeTriangles to 0 to force reading triangles from TriangleDataFileName
// The first time you render a particular surface, you will have
// set MakeTriangles to 1.


#declare TriangleDataFileName="klein1.dat" //**
// The name of a file to write/read triangles to/from.
// If making a new mesh, TriangleDataFileName is the
// name the triangles are written to so they can
// be used on another run without recalculating them.
// If MakeTriangles is set to 0, TriangleDataFileName is
// the file the triangles will be read from.

#declare use_smooth_triangles=1;//**
// If use_smooth_triangles is set to 0, only triangles (no normals) are generated
// There is currently no checking of what type of triangles (smooth or plane)
// they are when reading, so you have to use the same setting for use_smooth_triangles
// that was set when the triangles were written.

// If WriteRAW is set to non-zero, the triangles generated will (also) be written to
// the file named by WriteRAWto as RAW triangle data 
#declare WriteRAW=0;

#if(WriteRAW)
        #declare WriteRAWto="klein1.raw"
#end

/*--------------------------------------------------------*/   

// "//**" = required by p_surf.inc if we are making new triangles
#declare uusteps = 40;		//**
#declare vvsteps = 40;		//**

// Limits for the surface parameters 
#declare uumin   =  0;		//**
#declare uumax   =  2*pi;          //**
#declare vvmin   =  0; 		//**
#declare vvmax   =  2*pi; 	//**


/* Parametric equations for the particular surface we are making */
// the surface
#macro Klein1(uu,vv)

        #local rr= 4*(1-cos(uu)/2);
        #if(uu<pi)
                #local xx=6*cos(uu)*(1+sin(uu))+rr*cos(uu)*cos(vv);
                #local yy=16*sin(uu)+rr*sin(uu)*cos(vv);
        #else
                #local xx= 6*cos(uu)*(1+sin(uu))+rr*cos(vv+pi); 
                #local yy=16*sin(uu);
        #end        
        
        #local zz=rr*sin(vv);
        <xx,yy,zz>
#end

// Have to set XYZ to our desired surface.
// XYZ is the macro actually called in p_surf.inc
#macro XYZ(uu,vv)	//**
	Klein1(uu,vv)
#end


#if(MakeTriangles)
	#declare WriteTrianglesTo=TriangleDataFileName
	// to *not* write out a triangle datafile when MakeTriangles is 
	// set, just make sure WriteTrianglesTo is not defined.
        // (e.g. comment out the above line)
#else
	#declare ReadTrianglesFrom=TriangleDataFileName
#end                                                                     


/* --------Constructing the surface------------------------------------*/
#include "p_surf.inc" //**
// p_surf.inc uses the above declarations to make 
// a triangle mesh named 'p_surface'                        


object{
        p_surface // from p_surf.inc
        texture{                                                  
                pigment{color rgbt<.1,.4,.14,.85>}                 
                finish{reflection .25 phong .7 phong_size 100} 
        }          
  
        rotate <0,0,90>
        rotate <0,10,0>
        scale .8
}

camera
{ 
	location  < 16, 11,-16>
	look_at   < 0, 0, 0>
} 

light_source { <40, 50, -50> color rgb 1 }


sky_sphere
{
  pigment
  {   
    bozo    
    color_map {  [0.0 color DarkSlateGrey] [1.0 color rgb <0.7,0.7,1.0>]}
  }
}
