// Example/template scene file for using p_surf.inc

#include "colors.inc"

//global_settings { max_trace_level 8 }

#declare MakeTriangles=1; //**
// Set MakeTriangles to 1 to make surface from scratch.
// Set MakeTriangles to 0 to force reading triangles from TriangleDataFileName
// The first time you render a particular surface, you will have
// set MakeTriangles to 1.


#declare TriangleDataFileName="klein8.dat" //**
// The name of a file to write/read triangles to/from.
// If making a new mesh, TriangleDataFileName is the
// name the triangles are written to so they can
// be used on another run without recalculating them.
// If MakeTriangles is set to 0, TriangleDataFileName is
// the file the triangles will be read from.

#declare use_smooth_triangles=1;//**
// If use_smooth_triangles is set to 0, only triangles (no normals) are generated
// There is currently no checking of what type of triangles (smooth or plane)
// they are when reading, so you have to use the same setting for use_smooth_triangles
// that was set when the triangles were written.


/*--------------------------------------------------------*/   

// "//**" = required by p_surf.inc if we are making new triangles
#declare uusteps = 50;		//**
#declare vvsteps = 50;		//**

// Limits for the surface parameters 
#declare uumin   =  -pi;		//**
#declare uumax   =  pi;          //**
#declare vvmin   =  -pi; 		//**
#declare vvmax   =  pi; 	//**


/* Parametric equations for the particular surface we are making */
                                                                 
// a couple of 'utility functions'                                                                 
#macro Cosh(b)
	(exp(b)+exp(-b))/2
#end
#macro Sinh(b)
	(exp(b)-exp(-b))/2
#end


// the surface
#declare a=2;
#macro Klein8(uu,vv)
<   
cos(uu)*(a + sin(vv)*cos(uu/2) - sin(2*vv)*sin(uu/2)/2),
sin(uu)*(a + sin(vv)*cos(uu/2) - sin(2*vv)*sin(uu/2)/2),
sin(uu/2)*sin(vv) + cos(uu/2)*sin(2*vv)/2    
    
>
#end

// Have to set XYZ to our desired surface.
// XYZ is the macro actually called in p_surf.inc
#macro XYZ(uu,vv)	//**
	Klein8(uu,vv)
#end


#if(MakeTriangles)
	#declare WriteTrianglesTo=TriangleDataFileName
	// to *not* write out a triangle datafile when MakeTriangles is 
	// set, just make sure WriteTrianglesTo is not defined.
        // (e.g. comment out the above line)
#else
	#declare ReadTrianglesFrom=TriangleDataFileName
#end    
                                                                 
#include "textures.inc" 

#macro mytexture1(uucount,vvcount)

        #if (mod(uucount,2)=0)
                texture{
                        pigment{Yellow}
                        finish{phong 1 phong_size 20}
                }        
        #else   
                texture{pigment{Clear}}
        #end       

#end  


#declare WriteRAWto="klein8.raw"
/* --------Constructing the surface------------------------------------*/
#include "p_surf.inc" //**
// p_surf.inc uses the above declarations to make 
// a triangle mesh named 'p_surface'

object{
	union{
          object{
                        p_surface // from p_surf.inc
                        

                        texture{pigment{Yellow}}
          }
	}
	rotate <0,-90,0>
	scale 3
}

camera
{ 
	location  < 16, 11,-16>
	look_at   < 0, 0, 0>
} 

light_source { <20, 10, -20> color rgb 1 }


sky_sphere{pigment{Grey}}
 
